@@ -5,23 +5,27 @@ Chromecast.connect().
 
 You can use that functionality to include pychromecast into your main loop.
 """
+# pylint: disable=invalid-name
+
 import argparse
 import logging
 import select
 import time
 
-import pychromecast
 import zeroconf
 
+import pychromecast
+
 CAST_NAME = "Living Room"
 
-"""
-Check for cast.socket_client.get_socket() and
-handle it with cast.socket_client.run_once()
-"""
-
 
 def your_main_loop():
+    """
+    Main loop example.
+    Check for cast.socket_client.get_socket() and
+    handle it with cast.socket_client.run_once()
+    """
+
     t = 1
     cast = None
 
@@ -31,7 +35,6 @@ def your_main_loop():
             chromecast.connect()
             nonlocal cast
             cast = chromecast
-            pychromecast.discovery.stop_discovery(browser)
 
     browser = pychromecast.get_chromecasts(blocking=False, callback=callback)
 
@@ -49,16 +52,15 @@ def your_main_loop():
             if t > 50:
                 break
         else:
-            print("=> Waiting for discovery of cast '{}'...".format(args.cast))
+            print(f"=> Waiting for discovery of cast '{args.cast}'...")
         time.sleep(1)
 
-
-"""
-Your code which is called by main loop
-"""
+    print("All done, shutting down discovery")
+    browser.stop_discovery()
 
 
 def do_actions(cast, t):
+    """Your code which is called by main loop."""
     if t == 5:
         print()
         print("=> Sending non-blocking play_media command")
@@ -90,9 +92,7 @@ def do_actions(cast, t):
         print("Media status", cast.media_controller.status)
 
 
-parser = argparse.ArgumentParser(
-    description="Example on how to use the Media Controller to play an URL."
-)
+parser = argparse.ArgumentParser(description="Example without socket_client thread")
 parser.add_argument("--show-debug", help="Enable debug log", action="store_true")
 parser.add_argument(
     "--show-zeroconf-debug", help="Enable zeroconf debug log", action="store_true"
