@@ -1,29 +1,36 @@
 """
 Example that shows how the DashCast controller can be used.
 """
+# pylint: disable=invalid-name
 
 import argparse
 import logging
 import sys
 import time
 
-import pychromecast
-import pychromecast.controllers.dashcast as dashcast
 import zeroconf
 
+import pychromecast
+from pychromecast.controllers import dashcast
+
 # Change to the friendly name of your Chromecast
 CAST_NAME = "Living Room"
 
 parser = argparse.ArgumentParser(
-    description="Example on how to use the Media Controller to play an URL."
+    description="Example that shows how the DashCast controller can be used."
+)
+parser.add_argument(
+    "--cast", help='Name of cast device (default: "%(default)s")', default=CAST_NAME
+)
+parser.add_argument(
+    "--known-host",
+    help="Add known host (IP), can be used multiple times",
+    action="append",
 )
 parser.add_argument("--show-debug", help="Enable debug log", action="store_true")
 parser.add_argument(
     "--show-zeroconf-debug", help="Enable zeroconf debug log", action="store_true"
 )
-parser.add_argument(
-    "--cast", help='Name of cast device (default: "%(default)s")', default=CAST_NAME
-)
 args = parser.parse_args()
 
 if args.show_debug:
@@ -32,9 +39,11 @@ if args.show_zeroconf_debug:
     print("Zeroconf version: " + zeroconf.__version__)
     logging.getLogger("zeroconf").setLevel(logging.DEBUG)
 
-chromecasts, browser = pychromecast.get_listed_chromecasts(friendly_names=[args.cast])
+chromecasts, browser = pychromecast.get_listed_chromecasts(
+    friendly_names=[args.cast], known_hosts=args.known_host
+)
 if not chromecasts:
-    print('No chromecast with name "{}" discovered'.format(args.cast))
+    print(f'No chromecast with name "{args.cast}" discovered')
     sys.exit(1)
 
 cast = chromecasts[0]
@@ -77,4 +86,4 @@ if args.show_debug:
     time.sleep(10)
 
 # Shut down discovery
-pychromecast.discovery.stop_discovery(browser)
+browser.stop_discovery()
