@@ -1,14 +1,22 @@
 """
-Example that shows how to list available chromecasts.
+Example that shows how to list all available chromecasts.
 """
+# pylint: disable=invalid-name
+
 import argparse
 import logging
 
-import pychromecast
 import zeroconf
 
+import pychromecast
+
 parser = argparse.ArgumentParser(
-    description="Example on how to receive updates on discovered chromecasts."
+    description="Example that shows how to list all available chromecasts."
+)
+parser.add_argument(
+    "--known-host",
+    help="Add known host (IP), can be used multiple times",
+    action="append",
 )
 parser.add_argument("--show-debug", help="Enable debug log", action="store_true")
 parser.add_argument(
@@ -22,9 +30,11 @@ if args.show_zeroconf_debug:
     print("Zeroconf version: " + zeroconf.__version__)
     logging.getLogger("zeroconf").setLevel(logging.DEBUG)
 
-devices, browser = pychromecast.discovery.discover_chromecasts()
+devices, browser = pychromecast.discovery.discover_chromecasts(
+    known_hosts=args.known_host
+)
 # Shut down discovery
-pychromecast.stop_discovery(browser)
+browser.stop_discovery()
 
 print(f"Discovered {len(devices)} device(s):")
 for device in devices:
