@@ -2,15 +2,17 @@
 Example on how to use the Media Controller.
 
 """
+# pylint: disable=invalid-name
 
 import argparse
 import logging
 import sys
 import time
 
-import pychromecast
 import zeroconf
 
+import pychromecast
+
 # Change to the friendly name of your Chromecast
 CAST_NAME = "Living Room"
 
@@ -20,17 +22,22 @@ MEDIA_URL = (
 )
 
 parser = argparse.ArgumentParser(
-    description="Example on how to use the socket client without callbacks."
+    description="Example on how to use the Media Controller."
+)
+parser.add_argument(
+    "--cast", help='Name of cast device (default: "%(default)s")', default=CAST_NAME
+)
+parser.add_argument(
+    "--known-host",
+    help="Add known host (IP), can be used multiple times",
+    action="append",
 )
 parser.add_argument("--show-debug", help="Enable debug log", action="store_true")
-parser.add_argument(
-    "--show-zeroconf-debug", help="Enable zeroconf debug log", action="store_true"
-)
 parser.add_argument(
     "--show-status-only", help="Show status, then exit", action="store_true"
 )
 parser.add_argument(
-    "--cast", help='Name of cast device (default: "%(default)s")', default=CAST_NAME
+    "--show-zeroconf-debug", help="Enable zeroconf debug log", action="store_true"
 )
 parser.add_argument(
     "--url", help='Media url (default: "%(default)s")', default=MEDIA_URL
@@ -45,9 +52,11 @@ if args.show_zeroconf_debug:
     print("Zeroconf version: " + zeroconf.__version__)
     logging.getLogger("zeroconf").setLevel(logging.DEBUG)
 
-chromecasts, browser = pychromecast.get_listed_chromecasts(friendly_names=[args.cast])
+chromecasts, browser = pychromecast.get_listed_chromecasts(
+    friendly_names=[args.cast], known_hosts=args.known_host
+)
 if not chromecasts:
-    print('No chromecast with name "{}" discovered'.format(args.cast))
+    print(f'No chromecast with name "{args.cast}" discovered')
     sys.exit(1)
 
 cast = chromecasts[0]
@@ -75,7 +84,7 @@ if not cast.is_idle:
         time.sleep(0.1)
         t = t - 0.1
 
-print('Playing media "{}"'.format(args.url))
+print(f'Playing media "{args.url}"')
 cast.play_media(args.url, "video/mp4")
 
 t = 0
@@ -105,4 +114,4 @@ while True:
         break
 
 # Shut down discovery
-pychromecast.discovery.stop_discovery(browser)
+browser.stop_discovery()
