@@ -2,20 +2,25 @@
 Example showing how to create a simple Chromecast event listener for
 device and media status events
 """
+# pylint: disable=invalid-name
 
 import argparse
 import logging
 import sys
 import time
+import zeroconf
 
 import pychromecast
-import zeroconf
+from pychromecast.controllers.media import MediaStatusListener
+from pychromecast.controllers.receiver import CastStatusListener
 
 # Change to the friendly name of your Chromecast
 CAST_NAME = "Living Room Speaker"
 
 
-class StatusListener:
+class MyCastStatusListener(CastStatusListener):
+    """Cast status listener"""
+
     def __init__(self, name, cast):
         self.name = name
         self.cast = cast
@@ -25,7 +30,9 @@ class StatusListener:
         print(status)
 
 
-class StatusMediaListener:
+class MyMediaStatusListener(MediaStatusListener):
+    """Status media listener"""
+
     def __init__(self, name, cast):
         self.name = name
         self.cast = cast
@@ -38,13 +45,18 @@ class StatusMediaListener:
 parser = argparse.ArgumentParser(
     description="Example on how to create a simple Chromecast event listener."
 )
+parser.add_argument(
+    "--cast", help='Name of cast device (default: "%(default)s")', default=CAST_NAME
+)
+parser.add_argument(
+    "--known-host",
+    help="Add known host (IP), can be used multiple times",
+    action="append",
+)
 parser.add_argument("--show-debug", help="Enable debug log", action="store_true")
 parser.add_argument(
     "--show-zeroconf-debug", help="Enable zeroconf debug log", action="store_true"
 )
-parser.add_argument(
-    "--cast", help='Name of cast device (default: "%(default)s")', default=CAST_NAME
-)
 args = parser.parse_args()
 
 if args.show_debug:
@@ -53,22 +65,24 @@ if args.show_zeroconf_debug:
     print("Zeroconf version: " + zeroconf.__version__)
     logging.getLogger("zeroconf").setLevel(logging.DEBUG)
 
-chromecasts, browser = pychromecast.get_listed_chromecasts(friendly_names=[args.cast])
+chromecasts, browser = pychromecast.get_listed_chromecasts(
+    friendly_names=[args.cast], known_hosts=args.known_host
+)
 if not chromecasts:
-    print('No chromecast with name "{}" discovered'.format(args.cast))
+    print(f'No chromecast with name "{args.cast}" discovered')
     sys.exit(1)
 
 chromecast = chromecasts[0]
 # Start socket client's worker thread and wait for initial status update
 chromecast.wait()
 
-listenerCast = StatusListener(chromecast.name, chromecast)
+listenerCast = MyCastStatusListener(chromecast.name, chromecast)
 chromecast.register_status_listener(listenerCast)
 
-listenerMedia = StatusMediaListener(chromecast.name, chromecast)
+listenerMedia = MyMediaStatusListener(chromecast.name, chromecast)
 chromecast.media_controller.register_status_listener(listenerMedia)
 
 input("Listening for Chromecast events...\n\n")
 
 # Shut down discovery
-pychromecast.discovery.stop_discovery(browser)
+browser.stop_discovery()
