@@ -2,13 +2,16 @@
 Example on how to use the Supla Controller
 
 """
+# pylint: disable=invalid-name
+
 import logging
-import requests
+from time import sleep
 import sys
-from bs4 import BeautifulSoup
+
+import requests
+from bs4 import BeautifulSoup  # pylint: disable=import-error
 
 import pychromecast
-from time import sleep
 from pychromecast.controllers.supla import SuplaController
 
 
@@ -20,7 +23,7 @@ CAST_NAME = "Kitchen Speaker"
 PROGRAM = "aamulypsy"
 
 
-result = requests.get("https://www.supla.fi/ohjelmat/{}".format(PROGRAM))
+result = requests.get(f"https://www.supla.fi/ohjelmat/{PROGRAM}")
 soup = BeautifulSoup(result.content)
 MEDIA_ID = soup.select('a[title*="Koko Shitti"]')[0]["href"].split("/")[-1]
 print(MEDIA_ID)
@@ -30,7 +33,7 @@ logging.basicConfig(level=logging.DEBUG)
 
 chromecasts, browser = pychromecast.get_listed_chromecasts(friendly_names=[CAST_NAME])
 if not chromecasts:
-    print('No chromecast with name "{}" discovered'.format(CAST_NAME))
+    print(f'No chromecast with name "{CAST_NAME}" discovered')
     sys.exit(1)
 
 cast = chromecasts[0]
