@@ -5,24 +5,30 @@ import logging
 import fnmatch
 from threading import Event
 
-# pylint: disable=wildcard-import
 import threading
 
 import zeroconf
 
-from .config import *  # noqa
-from .error import *  # noqa
+from .config import *  # noqa: F403
+from .error import *  # noqa: F403
 from . import socket_client
-from .discovery import (  # noqa
+from .discovery import (  # noqa: F401
     DISCOVER_TIMEOUT,
-    CastListener,
+    CastBrowser,
+    CastListener,  # Deprecated
+    SimpleCastListener,
     discover_chromecasts,
     start_discovery,
     stop_discovery,
 )
 from .dial import get_device_status, DeviceStatus
-from .const import CAST_MANUFACTURERS, CAST_TYPES, CAST_TYPE_CHROMECAST
-from .controllers.media import STREAM_TYPE_BUFFERED  # noqa
+from .const import (  # noqa: F401
+    CAST_MANUFACTURERS,
+    CAST_TYPE_GROUP,
+    CAST_TYPES,
+    CAST_TYPE_CHROMECAST,
+)
+from .controllers.media import STREAM_TYPE_BUFFERED  # noqa: F401
 
 __all__ = ("__version__", "__version_info__", "get_chromecasts", "Chromecast")
 __version_info__ = ("0", "7", "6")
@@ -40,15 +46,21 @@ def get_chromecast_from_host(host, tries=None, retry_wait=None, timeout=None):
     # the primary source and the remaining will be fetched
     # later on.
     ip_address, port, uuid, model_name, friendly_name = host
-    _LOGGER.debug("_get_chromecast_from_host %s", host)
-    cast_type = CAST_TYPES.get(model_name.lower(), CAST_TYPE_CHROMECAST)
-    manufacturer = CAST_MANUFACTURERS.get(model_name.lower(), "Google Inc.")
+    _LOGGER.debug("get_chromecast_from_host %s", host)
+    cast_type = None
+    manufacturer = None
+    multizone_supported = None
+    if model_name.lower() == "google cast group":
+        cast_type = CAST_TYPE_GROUP
+        manufacturer = "Google Inc."
+        multizone_supported = False
     device = DeviceStatus(
         friendly_name=friendly_name,
         model_name=model_name,
         manufacturer=manufacturer,
         uuid=uuid,
         cast_type=cast_type,
+        multizone_supported=multizone_supported,
     )
     return Chromecast(
         host=ip_address,
@@ -64,23 +76,29 @@ def get_chromecast_from_host(host, tries=None, retry_wait=None, timeout=None):
 _get_chromecast_from_host = get_chromecast_from_host  # pylint: disable=invalid-name
 
 
-def get_chromecast_from_service(
-    services, zconf, tries=None, retry_wait=None, timeout=None
+def get_chromecast_from_cast_info(
+    cast_info, zconf, tries=None, retry_wait=None, timeout=None
 ):
     """Creates a Chromecast object from a zeroconf service."""
-    # Build device status from the mDNS service name info, this
+    # Build device status from the CastInfo, this
     # information is the primary source and the remaining will be
     # fetched later on.
-    services, uuid, model_name, friendly_name, _, _ = services
-    _LOGGER.debug("_get_chromecast_from_service %s", services)
-    cast_type = CAST_TYPES.get(model_name.lower(), CAST_TYPE_CHROMECAST)
-    manufacturer = CAST_MANUFACTURERS.get(model_name.lower(), "Google Inc.")
+    services = cast_info.services
+    _LOGGER.debug("get_chromecast_from_cast_info %s", services)
+    cast_type = None
+    manufacturer = None
+    multizone_supported = None
+    if cast_info.model_name.lower() == "google cast group":
+        cast_type = CAST_TYPE_GROUP
+        manufacturer = "Google Inc."
+        multizone_supported = False
     device = DeviceStatus(
-        friendly_name=friendly_name,
-        model_name=model_name,
+        friendly_name=cast_info.friendly_name,
+        model_name=cast_info.model_name,
         manufacturer=manufacturer,
-        uuid=uuid,
+        uuid=cast_info.uuid,
         cast_type=cast_type,
+        multizone_supported=multizone_supported,
     )
     return Chromecast(
         host=None,
@@ -95,7 +113,7 @@ def get_chromecast_from_service(
 
 # Alias for backwards compatibility
 _get_chromecast_from_service = (  # pylint: disable=invalid-name
-    get_chromecast_from_service
+    get_chromecast_from_cast_info
 )
 
 
@@ -107,6 +125,7 @@ def get_listed_chromecasts(
     timeout=None,
     discovery_timeout=DISCOVER_TIMEOUT,
     zeroconf_instance=None,
+    known_hosts=None,
 ):
     """
     Searches the network for chromecast devices matching a list of friendly
@@ -116,8 +135,7 @@ def get_listed_chromecasts(
       A list of Chromecast objects matching the criteria,
       or an empty list if no matching chromecasts were found.
       A service browser to keep the Chromecast mDNS data updated. When updates
-      are (no longer) needed, pass the browser object to
-      pychromecast.discovery.stop_discovery().
+      are (no longer) needed, call browser.stop_discovery().
 
     To only discover chromecast devices without connecting to them, use
     discover_listed_chromecasts instead.
@@ -134,20 +152,21 @@ def get_listed_chromecasts(
 
     cc_list = {}
 
-    def callback(uuid, name):  # pylint: disable=unused-argument
-        _LOGGER.debug("Found chromecast %s", uuid)
+    def add_callback(uuid, _service):
+        _LOGGER.debug(
+            "Found chromecast %s (%s)", browser.devices[uuid].friendly_name, uuid
+        )
 
         def get_chromecast_from_uuid(uuid):
-            return get_chromecast_from_service(
-                listener.services[uuid],
+            return get_chromecast_from_cast_info(
+                browser.devices[uuid],
                 zconf=zconf,
                 tries=tries,
                 retry_wait=retry_wait,
                 timeout=timeout,
             )
 
-        service = listener.services[uuid]
-        friendly_name = service[3]
+        friendly_name = browser.devices[uuid].friendly_name
         try:
             if uuids and uuid in uuids:
                 if uuid not in cc_list:
@@ -159,28 +178,28 @@ def get_listed_chromecasts(
                 friendly_names.remove(friendly_name)
             if not friendly_names and not uuids:
                 discover_complete.set()
-        except ChromecastConnectionError:  # noqa
+        except ChromecastConnectionError:  # noqa: F405
             pass
 
     discover_complete = Event()
 
-    listener = CastListener(callback)
     zconf = zeroconf_instance or zeroconf.Zeroconf()
-    browser = start_discovery(listener, zconf)
+    browser = CastBrowser(SimpleCastListener(add_callback), zconf, known_hosts)
+    browser.start_discovery()
 
     # Wait for the timeout or found all wanted devices
     discover_complete.wait(discovery_timeout)
     return (list(cc_list.values()), browser)
 
 
-# pylint: disable=too-many-locals
-def get_chromecasts(
+def get_chromecasts(  # pylint: disable=too-many-locals
     tries=None,
     retry_wait=None,
     timeout=None,
     blocking=True,
     callback=None,
     zeroconf_instance=None,
+    known_hosts=None,
 ):
     """
     Searches the network for chromecast devices and creates a Chromecast object
@@ -190,8 +209,7 @@ def get_chromecasts(
       A list of Chromecast objects, or an empty list if no matching chromecasts were
       found.
       A service browser to keep the Chromecast mDNS data updated. When updates
-      are (no longer) needed, pass the browser object to
-      pychromecast.discovery.stop_discovery().
+      are (no longer) needed, call browser.stop_discovery().
 
     To only discover chromecast devices without connecting to them, use
     discover_chromecasts instead.
@@ -215,20 +233,20 @@ def get_chromecasts(
     """
     if blocking:
         # Thread blocking chromecast discovery
-        services, browser = discover_chromecasts()
+        devices, browser = discover_chromecasts(known_hosts=known_hosts)
         cc_list = []
-        for service in services:
+        for device in devices:
             try:
                 cc_list.append(
-                    get_chromecast_from_service(
-                        service,
+                    get_chromecast_from_cast_info(
+                        device,
                         browser.zc,
                         tries=tries,
                         retry_wait=retry_wait,
                         timeout=timeout,
                     )
                 )
-            except ChromecastConnectionError:  # noqa
+            except ChromecastConnectionError:  # noqa: F405
                 pass
         return (cc_list, browser)
 
@@ -238,14 +256,14 @@ def get_chromecasts(
 
     known_uuids = set()
 
-    def internal_callback(uuid, name):  # pylint: disable=unused-argument
+    def add_callback(uuid, _service):
         """Called when zeroconf has discovered a new chromecast."""
         if uuid in known_uuids:
             return
         try:
             callback(
-                get_chromecast_from_service(
-                    listener.services[uuid],
+                get_chromecast_from_cast_info(
+                    browser.devices[uuid],
                     zconf=zconf,
                     tries=tries,
                     retry_wait=retry_wait,
@@ -253,12 +271,12 @@ def get_chromecasts(
                 )
             )
             known_uuids.add(uuid)
-        except ChromecastConnectionError:  # noqa
+        except ChromecastConnectionError:  # noqa: F405
             pass
 
-    listener = CastListener(internal_callback)
     zconf = zeroconf_instance or zeroconf.Zeroconf()
-    browser = start_discovery(listener, zconf)
+    browser = CastBrowser(SimpleCastListener(add_callback), zconf, known_hosts)
+    browser.start_discovery()
     return browser
 
 
@@ -280,7 +298,7 @@ class Chromecast:
     :param retry_wait: A floating point number specifying how many seconds to
                        wait between each retry. None means to use the default
                        which is 5 seconds.
-    :param services: A list of mDNS services to try to connect to. If present,
+    :param services: A set of mDNS or host services to try to connect to. If present,
                      parameters host and port are ignored and host and port are
                      instead resolved through mDNS. The list of services may be
                      modified, for example if speaker group leadership is handed
@@ -318,6 +336,9 @@ class Chromecast:
                     manufacturer=(device.manufacturer or dev_status.manufacturer),
                     uuid=(device.uuid or dev_status.uuid),
                     cast_type=(device.cast_type or dev_status.cast_type),
+                    multizone_supported=(
+                        device.multizone_supported or dev_status.multizone_supported
+                    ),
                 )
             else:
                 self.device = device
@@ -325,8 +346,8 @@ class Chromecast:
             self.device = get_device_status(host, services, zconf)
 
         if not self.device:
-            raise ChromecastConnectionError(  # noqa
-                "Could not connect to {}:{}".format(host, port or 8009)
+            raise ChromecastConnectionError(  # noqa: F405
+                f"Could not connect to {host}:{port or 8009}"
             )
 
         self.status = None
@@ -361,17 +382,15 @@ class Chromecast:
 
     @property
     def ignore_cec(self):
-        """ Returns whether the CEC data should be ignored. """
+        """Returns whether the CEC data should be ignored."""
         return self.device is not None and any(
-            [
-                fnmatch.fnmatchcase(self.device.friendly_name, pattern)
-                for pattern in IGNORE_CEC
-            ]
+            fnmatch.fnmatchcase(self.device.friendly_name, pattern)
+            for pattern in IGNORE_CEC
         )
 
     @property
     def is_idle(self):
-        """ Returns if there is currently an app running. """
+        """Returns if there is currently an app running."""
         return (
             self.status is None
             or self.app_id in (None, IDLE_APP_ID)
@@ -384,7 +403,7 @@ class Chromecast:
 
     @property
     def uuid(self):
-        """ Returns the unique UUID of the Chromecast device. """
+        """Returns the unique UUID of the Chromecast device."""
         return self.device.uuid
 
     @property
@@ -397,12 +416,12 @@ class Chromecast:
 
     @property
     def uri(self):
-        """ Returns the device URI (ip:port) """
-        return "{}:{}".format(self.socket_client.host, self.socket_client.port)
+        """Returns the device URI (ip:port)"""
+        return f"{self.socket_client.host}:{self.socket_client.port}"
 
     @property
     def model_name(self):
-        """ Returns the model name of the Chromecast device. """
+        """Returns the model name of the Chromecast device."""
         return self.device.model_name
 
     @property
@@ -420,33 +439,33 @@ class Chromecast:
 
     @property
     def app_id(self):
-        """ Returns the current app_id. """
+        """Returns the current app_id."""
         return self.status.app_id if self.status else None
 
     @property
     def app_display_name(self):
-        """ Returns the name of the current running app. """
+        """Returns the name of the current running app."""
         return self.status.display_name if self.status else None
 
     @property
     def media_controller(self):
-        """ Returns the media controller. """
+        """Returns the media controller."""
         return self.socket_client.media_controller
 
     def new_cast_status(self, status):
-        """ Called when a new status received from the Chromecast. """
+        """Called when a new status received from the Chromecast."""
         self.status = status
         if status:
             self.status_event.set()
 
     def start_app(self, app_id, force_launch=False):
-        """ Start an app on the Chromecast. """
+        """Start an app on the Chromecast."""
         self.logger.info("Starting app %s", app_id)
 
         self.socket_client.receiver_controller.launch_app(app_id, force_launch)
 
     def quit_app(self):
-        """ Tells the Chromecast to quit current app_id. """
+        """Tells the Chromecast to quit current app_id."""
         self.logger.info("Quiting current app")
 
         self.socket_client.receiver_controller.stop_app()
@@ -457,9 +476,7 @@ class Chromecast:
 
         """
         if delta <= 0:
-            raise ValueError(
-                "volume delta must be greater than zero, not {}".format(delta)
-            )
+            raise ValueError(f"volume delta must be greater than zero, not {delta}")
         return self.set_volume(self.status.volume_level + delta)
 
     def volume_down(self, delta=0.1):
@@ -467,9 +484,7 @@ class Chromecast:
         Returns the new volume.
         """
         if delta <= 0:
-            raise ValueError(
-                "volume delta must be greater than zero, not {}".format(delta)
-            )
+            raise ValueError(f"volume delta must be greater than zero, not {delta}")
         return self.set_volume(self.status.volume_level - delta)
 
     def wait(self, timeout=None):
@@ -535,16 +550,14 @@ class Chromecast:
             pass
 
     def __repr__(self):
-        txt = "Chromecast({!r}, port={!r}, device={!r})".format(
-            self.socket_client.host, self.socket_client.port, self.device
+        return (
+            f"Chromecast({self.socket_client.host!r}, port={self.socket_client.port!r}, "
+            f"device={self.device!r})"
         )
-        return txt
 
     def __unicode__(self):
-        return "Chromecast({}, {}, {}, {}, {})".format(
-            self.socket_client.host,
-            self.socket_client.port,
-            self.device.friendly_name,
-            self.device.model_name,
-            self.device.manufacturer,
+        return (
+            f"Chromecast({self.socket_client.host}, {self.socket_client.port}, "
+            f"{self.device.friendly_name}, {self.device.model_name}, "
+            f"{self.device.manufacturer})"
         )
