@@ -7,14 +7,13 @@ from .media import MediaController
 
 
 class BubbleUPNPController(MediaController):
-    """ Controller to interact with BubbleUPNP app namespace. """
+    """Controller to interact with BubbleUPNP app namespace."""
 
-    # pylint: disable=useless-super-delegation
     def __init__(self):
-        super(BubbleUPNPController, self).__init__()
+        super().__init__()
         self.app_id = APP_BUBBLEUPNP
         self.supporting_app_id = APP_BUBBLEUPNP
 
     def quick_play(self, media_id=None, media_type="video/mp4", **kwargs):
-        """ Quick Play """
+        """Quick Play"""
         self.play_media(media_id, media_type, **kwargs)
