@@ -1,7 +1,7 @@
 """
 Controller to interface with Home Assistant
 """
-from ..config import APP_HOME_ASSISTANT
+from ..config import APP_HOMEASSISTANT_LOVELACE
 from . import BaseController
 
 
@@ -9,7 +9,7 @@ APP_NAMESPACE = "urn:x-cast:com.nabucasa.hast"
 
 
 class HomeAssistantController(BaseController):
-    """ Controller to interact with Home Assistant. """
+    """Controller to interact with Home Assistant."""
 
     def __init__(
         self,
@@ -17,7 +17,7 @@ class HomeAssistantController(BaseController):
         client_id,
         refresh_token,
         app_namespace=APP_NAMESPACE,
-        app_id=APP_HOME_ASSISTANT,
+        app_id=APP_HOMEASSISTANT_LOVELACE,
     ):
         super().__init__(app_namespace, app_id)
         self.hass_url = hass_url
@@ -47,10 +47,10 @@ class HomeAssistantController(BaseController):
         self.get_status()
 
     def channel_disconnected(self):
-        """ Called when a channel is disconnected. """
+        """Called when a channel is disconnected."""
         self.status = None
 
-    def receive_message(self, message, data: dict):
+    def receive_message(self, _message, data: dict):
         """Called when a message is received."""
         if data.get("type") == "receiver_status":
             was_connected = self.hass_connected
