@@ -3,8 +3,10 @@
 from .controllers.youtube import YouTubeController
 from .controllers.supla import SuplaController
 from .controllers.yleareena import YleAreenaController
-from .controllers.spotify import SpotifyController
 from .controllers.bubbleupnp import BubbleUPNPController
+from .controllers.bbciplayer import BbcIplayerController
+from .controllers.bbcsounds import BbcSoundsController
+from .controllers.homeassistant_media import HomeAssistantMediaController
 
 
 def quick_play(cast, app_name, data):
@@ -56,12 +58,17 @@ def quick_play(cast, app_name, data):
         controller = SuplaController()
     elif app_name == "yleareena":
         controller = YleAreenaController()
-    elif app_name == "spotify":
-        controller = SpotifyController()
     elif app_name == "bubbleupnp":
         controller = BubbleUPNPController()
+    elif app_name == "bbciplayer":
+        controller = BbcIplayerController()
+    elif app_name == "bbcsounds":
+        controller = BbcSoundsController()
+    elif app_name == "homeassistant_media":
+        controller = HomeAssistantMediaController()
     else:
         raise NotImplementedError()
 
     cast.register_handler(controller)
+
     controller.quick_play(**data)
